#!/usr/bin/env python

import os
import getopt,sys
import string
import signal
import stat
import subprocess

mainpath = os.path.abspath("/")

excludes = ["/dev", "/proc", "/lost+found", "/tmp", "/sys", "/cdrom", "/selinux", "/var/tmp"]
errors = []

def on_terminate(sig, frame):
    if len(errors) > 0:
        print >> sys.stderr, "\nErrors while backingup the rights:\n------------------------------------"
        
        for error in errors:
            print >> sys.stderr, error

    print >> sys.stderr, "\n\nprocess terminated with signal %s on frame %s" % (sig, frame)
    
    sys.exit(1)

def walkpath(path, callback):
    if path in excludes:
        return
    
    try:
        st = os.stat(path)
        stmode = st[stat.ST_MODE]
        
        if not os.path.exists(path):
            return
        if stat.S_ISCHR(stmode) or stat.S_ISBLK(stmode) or stat.S_ISSOCK(stmode):
            return
        if os.path.islink(path):
            return
        
        callback(path, st)

    except Exception, e:
        errors.append("Exception %s on %s" % (e, path))
        return

    for f in os.listdir(path):
        fpath = os.path.join(path, f)

        try:
            st = os.stat(fpath)
            stmode = st[stat.ST_MODE]

            if f in excludes or fpath in excludes:
                continue
            if stat.S_ISCHR(stmode) or stat.S_ISBLK(stmode) or stat.S_ISSOCK(stmode):
                continue
            if os.path.islink(fpath):
                continue
            if stat.S_ISDIR(stmode):
                walkpath(fpath, callback)
                #continue

            callback(fpath, st)
        except Exception, e:
            errors.append("Exception %s on %s" % (e, fpath))
            continue

def backuprights(path, statinfo):
    try:
        if stat.S_ISREG(statinfo[stat.ST_MODE]):
            proc = subprocess.Popen(["lsattr", path], shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            attrs = proc.communicate()[0].strip().split(' ')[0].replace('-', '')

            print "%s;%o;%i;%i;%s" % (path, stat.S_IMODE(statinfo.st_mode), statinfo.st_uid, statinfo.st_gid, attrs)
    
        if stat.S_ISDIR(statinfo[stat.ST_MODE]):
            print "%s;%o;%i;%i;" % (path, stat.S_IMODE(statinfo.st_mode), statinfo.st_uid, statinfo.st_gid)
    except Exception, e:
        errors.append("Exception %s on %s" % (e, fpath))
    

if __name__ == '__main__':
    try:
        mainpath = sys.argv[1]
    except Exception, e:
        mainpath = os.path.abspath("/")
    
    #Registering signals
    signal.signal(signal.SIGINT, on_terminate)
    signal.signal(signal.SIGTSTP, on_terminate)
    signal.signal(signal.SIGSEGV, on_terminate)
    signal.signal(signal.SIGTERM, on_terminate)

    walkpath(mainpath, backuprights)

    if len(errors) > 0:
        print >> sys.stderr, "\nErrors while backingup the rights:\n------------------------------------"
        
        for error in errors:
            print >> sys.stderr, error

