#!/usr/bin/env python
#
# Watches your watchfolder and adds all the torrents to transmission
# after adding the torrent will be deleted
#

import os
import getopt,sys
import string
import signal
import stat
import subprocess

watchfolder = '/media/data2/Downloads/torrent'
transmissionremotecmd = '/usr/bin/transmission-remote'
transmissionhost = '127.0.0.1:9091'
transmissionuser = 'transmission'
transmissionpasswd = 'transmission'


excludes = []
errors = []

def add_torrent(filename):
    command = [transmissionremotecmd, transmissionhost, '--auth', ("%s:%s" % (transmissionuser, transmissionpasswd)), '--add', filename]
    #print filename
    #print command
    p = subprocess.Popen(command)
    if p.wait() != 0:
        errors.append("Couldn't add file (%s) with the following command: \"%s\". File not removed!" % (filename, ' '.join(command)))
    else:
        print "removing file: %s" % (filename)

def is_torrent(filename):
    if not os.path.exists(filename):
        return False
    if filename.endswith(".torrent"):
        return True
    return False

def on_terminate(sig, frame):
    if len(errors) > 0:
        print >> sys.stderr, "\nErrors found:\n------------------------------------"
        
        for error in errors:
            print >> sys.stderr, error
    
    print >> sys.stderr, "\n\nprocess terminated with signal %s on frame %s" % (sig, frame)
    
    sys.exit(1)

def walkpath(path, callback):
    if path in excludes:
        return
    
    try:
        st = os.stat(path)
        stmode = st[stat.ST_MODE]
        
        if not os.path.exists(path):
            return
        if stat.S_ISCHR(stmode) or stat.S_ISBLK(stmode) or stat.S_ISSOCK(stmode):
            return
        if os.path.islink(path):
            return
        
        if is_torrent(path):
        	callback(path)
    
    except Exception, e:
        errors.append("Exception %s on %s" % (e, path))
        return
    
    for f in os.listdir(path):
        fpath = os.path.join(path, f)

        try:
            st = os.stat(fpath)
            stmode = st[stat.ST_MODE]

            if f in excludes or fpath in excludes:
                continue
            if stat.S_ISCHR(stmode) or stat.S_ISBLK(stmode) or stat.S_ISSOCK(stmode):
                continue
            if os.path.islink(fpath):
                continue
            if stat.S_ISDIR(stmode):
                walkpath(fpath, callback)
                continue
            
            if is_torrent(fpath):
                callback(fpath)
        except Exception, e:
            errors.append("Exception %s on %s" % (e, fpath))
            continue

if __name__ == '__main__':
    try:
        watchfolder = sys.argv[1]
    except Exception, e:
    	print "Using the default folder: %s" % (watchfolder)
    
    watchfolder = os.path.abspath(watchfolder)
    
    if not os.path.exists(transmissionremotecmd):
        errors.append("Transmission remote command does not exists on: %s" % (transmissionremotecmd))
	#Registering signals
    signal.signal(signal.SIGINT, on_terminate)
    signal.signal(signal.SIGTSTP, on_terminate)
    signal.signal(signal.SIGSEGV, on_terminate)
    signal.signal(signal.SIGTERM, on_terminate)
    
    if len(errors) == 0:
        walkpath(watchfolder, add_torrent)
    
    if len(errors) > 0:
        print >> sys.stderr, "\nErrors found:\n------------------------------------"
        
        for error in errors:
            print >> sys.stderr, error
        sys.exit(1)

