#!/bin/bash

HOMELOC=/home

diskspaceusage() {
	df --sync -h $1 | awk '{print $5}' | grep % | grep -v Use | sort -n | tail -1 | cut -d "%" -f1 -
}


cleanHomedirs() {
    echo "* Cleaning homedirectories" 
    for HOMEDIR in `ls -1 $HOMELOC`; do
        if [ -d "$HOMELOC/$HOMEDIR" ]; then
        	find "$HOMELOC/$HOMEDIR" -name core -type f -size +1M -delete
        	find "$HOMELOC/$HOMEDIR" -regex 'core\.[0-9]+$' -type f -size +1M -delete
            rm -f "$HOMELOC/$HOMEDIR/core*" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.Trash/*" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.nx" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.local/share/Trash/info/*" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.local/share/Trash/files/*" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.thumbnails" > /dev/null 2>&1
            rm -rf "$HOMELOC/$HOMEDIR/.openoffice.org" > /dev/null 2>&1

            for PROFILEDIR in `ls -1A $HOMELOC/$HOMEDIR/.mozilla/firefox`; do
                if [ -d "$HOMELOC/$HOMEDIR/.mozilla/firefox/$PROFILEDIR" ]; then
                	rm -rf "$HOMELOC/$HOMEDIR/.mozilla/firefox/$PROFILEDIR/Cache/*"
                fi
            done
        fi
	done
	
	#remove dubious files
	find "$HOMELOC" -iname *.pif -type f -delete
	find "$HOMELOC" -iname *.cmd -type f -delete
	find "$HOMELOC" -iname *.scr -type f -delete
	find "$HOMELOC" -iname *.lnk -type f -delete
	

    echo "* Cleaning homedirectories which using to much disk space (only when over quota)" 
    for HOMEDIR in `repquota -a | grep days | grep -v Block | awk '{ print $1; } '`; do
        if [ -d "$HOMELOC/$HOMEDIR" ]; then
        	find "$HOMELOC/$HOMEDIR" -type f -size +30M -delete
        fi
    done

    
    echo "* More aggresive cleaning homedirectories (only when over quota)" 
    for homedir in `repquota -a | grep days | grep -v Block | awk '{ print $1; } '`; do
    	if [ -d "$HOMELOC/$HOMEDIR" ]; then
        	find "$HOMELOC/$HOMEDIR" -type f -size +4M -delete
        fi
    done

    #find "$HOMELOC" -type f -size +30M -delete
}

cleanAPT() {
    echo "* Cleaning APT cache" 
    aptitude autoclean > /dev/null 2>&1
    aptitude clean > /dev/null 2>&1
}

cleanTMP() {
    echo "* Cleaning TMP files" 
    rm -rf /var/tmp/* > /dev/null 2>&1
    rm -rf /tmp/* > /dev/null 2>&1
}

cleanLogFiles() {
    echo "* Cleaning Log files" 
    
    #remove files older then 10 days
	find /var/log -mtime +10 -delete
    
    if [ -x "/etc/cron.daily/logrotate" ]; then
    	/etc/cron.daily/logrotate
   	fi
	
	for FILE in `find /var/log -type f -size +10M | grep -vi mysql | grep -vi sql`; do
		if [ -f "$FILE" ]; then
			echo "\t\t* To large file: $FILE   clearing it."
			echo "" > "$FILE"
		fi
	done
}

cleanSquid() {
	# only do this if the squid cache dir can be even found
	if [ -d "/var/cache/spool/squid3" ] || [ -d "/var/cache/spool/squid" ]; then
		echo "* Cleaning Squid cache" 
		
		if [ -x "/etc/init.d/squid3"]; then
			/etc/init.d/squid3 stop > /dev/null 2>&1
			sleep 2
			killall -9 squid3
		fi
		
		if [ -x "/etc/init.d/squid"]; then
			/etc/init.d/squid stop > /dev/null 2>&1
			sleep 2
			killall -9 squid
		fi
	
		if [ -d "/var/cache/spool/squid3" ]; then
			rm -rf /var/cache/spool/squid3/* >/dev/null
		fi
		if [ -d "/var/cache/spool/squid" ]; then
			rm -rf /var/cache/spool/squid/* >/dev/null
		fi
		
		if [ -x "`which squid3`" ]; then
			`which squid3` -z > /dev/null
		fi
		
		if [ -x "`which squid`" ]; then
			`which squid` -z > /dev/null
		fi
		
		if [ -x "/etc/init.d/squid3"]; then
			/etc/init.d/squid3 start > /dev/null 2>&1
		fi
		
		if [ -x "/etc/init.d/squid"]; then
			/etc/init.d/squid start > /dev/null 2>&1
		fi
	fi
}

if [ "`diskspaceusage /`" -gt 95 ]; then
	echo "* Cleaning root directory"
	cleanAPT
fi

if [ "`diskspaceusage $HOMELOC`" -gt 95 ]; then
	echo "* Cleaning homedirectories"
	cleanHomedirs
fi

if [ "`diskspaceusage /var/log`" -gt 95 ]; then
	echo "* Cleaning log files"
	cleanLogFiles
fi

if [ "`diskspaceusage /tmp`" -gt 95 ]; then
	echo "* Cleaning temp files"
	cleanTMP
fi

if [ "`diskspaceusage /var/cache/apt`" -gt 95 ] || [ "`diskspaceusage /var/lib/dpkg`" -gt 95 ]; then
	echo "* Cleaning APT cache"
	cleanAPT
fi

if [ "`diskspaceusage /var/cache/spool`" -gt 95 ]; then
	echo "* Cleaning spool directory"
	cleanSquid
fi
