#!/bin/bash
#
# Author: Michiel Eghuizen (Eduwijs)
# Date:   2006-05-21
# Licence: GPL 2.0
# Changelog: Cf. wiki history of http://wiki.debian.org/DebianEdu/HowTo/AutoNetRespawn
#
# A tool which must be run in a cron job, to monitor the network.
# If the network is down, it will restart the network script,
# so you IP settings will be reloaded and it will execute some custom commands,
# for example stop the OpenVPN server, or reset the IPTables script.

#. ../config/CONFIG

LOGFILE="/var/log/netguard.log"
CHECKIP="$GATEWAY"                 ## Internet gateway

NETWORKSCRIPT="/etc/init.d/networking restart"
BRIDGEUTIL="/usr/sbin/brctl"
IPTABLESSAVE="/sbin/iptables-save"

# Commands to execute when the connection is down
# This will be run before the network script is restarted
execprecommands () {
	/etc/init.d/openvpn stop &> /dev/null
	killall -9 dhclient
	
	#flush IP tables
	iptables -F
	iptables -X
	iptables -t nat -F
	iptables -t nat -X
	iptables -t mangle -F
	iptables -t mangle -X
	iptables -P INPUT ACCEPT
	iptables -P FORWARD ACCEPT
	iptables -P OUTPUT ACCEPT
}

# Commands to execute when the connection is down
# This will be run after the network script is restarted
execpostcommands () {
	/etc/init.d/ssh restart > /dev/null 2>&1
	/etc/init.d/slapd restart > /dev/null 2>&1
	/etc/init.d/dhcp3-server restart > /dev/null 2>&1
	/etc/init.d/tftpd-hpa restart > /dev/null 2>&1
	/etc/init.d/nscd restart > /dev/null 2>&1
	/etc/init.d/freeradius restart > /dev/null 2>&1
	/etc/init.d/squid3 restart > /dev/null 2>&1

#	ssh -l username -nNT -R 1100:127.0.0.1:22 <remotehost>
}

# Check if logfile exists, if not then create a new one
if [ ! -e "$LOGFILE" ]; then
    touch $LOGFILE &> /dev/null
fi

# Check if i have write permissions
if [ ! -w "$LOGFILE" ]; then
    echo "You don't have write permissions to write to the log file."
    echo "Because the log file is in this script an important file, this script will be closed."
    echo ""
    echo "Debug info:"
    echo "logfile: $LOGFILE"
    echo "user: " `whoami`

    exit 1
fi

ping -c 1 $CHECKIP > /dev/null

if [ "$?" != "0" ]; then
    echo "[NetGuard]" >> $LOGFILE
    echo "===============================" >> $LOGFILE
    echo "Status: Network is down!" >> $LOGFILE
    echo "Time: " `date` >> $LOGFILE
    echo "Current network configuration: " >> $LOGFILE
    /sbin/ifconfig >> $LOGFILE
   
    echo "Route configuration: " >> $LOGFILE
    /sbin/route >> $LOGFILE

    if [ -e "$BRIDGEUTIL" ]; then
        echo "Bridge configuration: " >> $LOGFILE
        $BRIDGEUTIL show >> $LOGFILE
    fi

    if [ -e "$IPTABLESSAVE" ]; then
        echo "IP tables: " >> $LOGFILE
        $IPTABLESSAVE >> $LOGFILE
    fi

    execprecommands

    echo "Network script restart output: " >> $LOGFILE
    $NETWORKSCRIPT >> $LOGFILE
	
    execpostcommands

    ping -c 1 $CHECKIP > /dev/null
   
    if [ "$?" == "0" ]; then
        echo "Restart status: successful" >> $LOGFILE
    else
        echo "Restart status: FAILED" >> $LOGFILE
    fi
   
    echo "===============================" >> $LOGFILE
    echo "" >> $LOGFILE
fi

